/*
 * Copyright (c) 2005-2007 CodeDroids ApS (http://www.codedroids.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * For further information about CodeDroids ApS, please see the
 * company website: http://www.codedroids.com
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * $LastChangedRevision: 118 $
 * $LastChangedDate: 2007-02-20 17:26:56 +0100 (Tue, 20 Feb 2007) $
 * 
 */

package com.codedroids.oc.freemarker;

import freemarker.template.*;
import org.opencms.file.*;
import org.opencms.main.*;
import java.util.*;

public class VFSResourcePropertyModel implements TemplateHashModel {

	
	CmsObject co;
	String resName;
	Map defaults;
	boolean search;
	
	public VFSResourcePropertyModel(CmsObject co, String resName) {
		this(co, resName, false);
	}
	
	public VFSResourcePropertyModel(CmsObject co, String resName, boolean search) {
		this(co, resName, search, new HashMap());
	}
	
	public VFSResourcePropertyModel(CmsObject co, String resName, boolean search, Map defaults) {
		super();
		this.co = co;
		this.resName = resName;
		this.search = search;
		this.defaults = defaults;
	}
	
	public TemplateModel get(String key)
	{
		String value = null;
		try { 
			CmsProperty prop = co.readPropertyObject(resName, key, search);
			value = prop.getValue((String)defaults.get(key));
		} catch (CmsException e) {
			value = "??? "+resName+" ("+key+") ???"; // just to do something if the file is not readable.
		}
		return value == null ? null : new SimpleScalar(value);
	}
	
	public boolean isEmpty()
	{
		return false; // kind of expensive to try to find out whether or not this is the case so we say it isn't
	}
	
	

}
